#!/usr/bin/env python3

import socket
import argparse


def start_server(host='127.0.0.1', port=10000):
    # Create a TCP/IP socket
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as server_socket:
        server_socket.bind((host, port))
        server_socket.listen()
        with open("output.txt", "a") as f:
            f.write("Server Ready\n")
        while True:
            client_socket, client_address = server_socket.accept()
            with client_socket:
                # Receive the data from the client in chunks and write
                # to a file
                data = client_socket.recv(1024)
                while data:
                    with open("output.txt", "a") as f:
                        f.write(data.decode())
                    data = client_socket.recv(1024)


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    group = parser.add_argument_group()
    group.add_argument("-i", "--bind-host")
    group.add_argument("-p", "--bind-port", type=int)
    args = parser.parse_args()

    start_server(args.bind_host, args.bind_port)



#!/usr/bin/env python3

import socket
import time
import argparse


def send_data_from_fifo_to_server(
    fifo_path='/tmp/myfifo', host='127.0.0.1', port=10000
):
    # Open the FIFO for reading (blocking mode)
    with open(fifo_path, 'r') as fifo_file:
        with socket.socket(
            socket.AF_INET, socket.SOCK_STREAM
        ) as client_socket:
            client_socket.connect((host, port))
            # Continuously read from the FIFO and send to the server
            while True:
                data = fifo_file.readline()
                if data:
                    client_socket.sendall(data.encode())
                else:
                    time.sleep(0.1)


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    group = parser.add_argument_group()
    group.add_argument("-f", "--fifo_path")
    group.add_argument("-i", "--server-host")
    group.add_argument("-p", "--server-port", type=int)
    args = parser.parse_args()

    send_data_from_fifo_to_server(
        args.fifo_path, args.server_host, args.server_port
    )
